@@ -5,7 +5,7 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  http://statnet.org/attribution
 #
-#  Copyright 2008-2017 Statnet Commons
+#  Copyright 2008-2018 Statnet Commons
 #######################################################################
 #========================================================================
 # This file contains the following 3 functions for simulating stergms
@@ -80,6 +80,239 @@
 #
 ###############################################################################
 
+
+
+#' Draw from the distribution of an Separable Temporal Exponential Family
+#' Random Graph Model
+#' 
+#' \code{\link[stats]{simulate}} is used to draw from separable temporal
+#' exponential family random network models in their natural parameterizations.
+#' See \code{\link{stergm}} for more information on these models.
+#' 
+#' The dynamic process is run forward and the results are returned. For the
+#' method for \code{\link{networkDynamic}}, the simulation is resumed from the
+#' last generated time point of \code{object}, by default with the same model
+#' and parameters.
+#' 
+#' The starting network for the \code{\link{stergm}} object method
+#' (\code{simulate.stergm}) is determined by the \code{nw.start} argument.
+#' 
+#'   \itemize{
+#'    \item{If \code{time.start} is specified, it is used as the initial
+#'      time index of the simulation.}
+#'    \item{If \code{time.start} is not specified (is \code{NULL}), then
+#'      if the \code{object} carries a time stamp from which to start
+#'      or resume the simulation, either in the form
+#'      of a \code{"time"} network attribute (for the
+#'      \code{\link{network}} method --- see the
+#'      \code{\link{lasttoggle}} "API") or
+#'      in the form of an \code{\link{net.obs.period}} network attribute (for the
+#'      \code{\link{networkDynamic}} method), this attribute will be used. (If
+#'      specified, \code{time.start} will override it with a warning.)
+#'    }
+#'    \item{Othewise, the simulation starts at 0.}
+#'  }
+#' 
+#' @aliases simulate.stergm simulate.network simulate.networkDynamic
+#' @param object an object of type \code{\link{stergm}} giving a model fit or
+#' of type \code{\link{network}} giving the initial network.
+#' 
+#' \code{simulate.network} understands the \code{\link{lasttoggle}} "API".
+#' @param formation,dissolution One-sided \code{\link{ergm}}-style formulas for
+#' the formation and dissolution models, respectively.
+#' @param nsim Number of replications (separate chains of networks) of the
+#' process to run and return. The \code{\link{networkDynamic}} method only
+#' supports \code{nsim=1}.
+#' @param seed Random number integer seed.  See \code{\link[base]{set.seed}}.
+#' @param coef.form Parameters for the model from which the post-formation
+#' network is drawn.
+#' @param coef.diss As \code{coef.form}, but for the post-dissolution network.
+#' @param constraints A one-sided formula specifying one or more constraints on
+#' the support of the distribution of the networks being modeled, using syntax
+#' similar to the \code{formula} argument. Multiple constraints may be given,
+#' separated by \dQuote{+} operators.  Together with the model terms in the
+#' formula and the reference measure, the constraints define the distribution
+#' of networks being modeled.
+#' 
+#' It is also possible to specify a proposal function directly by passing a
+#' string with the function's name. In that case, arguments to the proposal
+#' should be specified through the \code{prop.args} argument to
+#' \code{\link{control.ergm}}.
+#' 
+#' The default is \code{~.}, for an unconstrained model.
+#' 
+#' See the [ERGM constraints][ergm-constraints] documentation for the
+#' constraints implemented in the **[ergm][ergm-package]** package.
+#' Other packages may add their own constraints.
+#' 
+#' For STERGMs in particular, the constraints apply to the post-formation and
+#' the post-dissolution network, rather than the final network. This means, for
+#' example, that if the degree of all vertices is constrained to be less than
+#' or equal to three, and a vertex begins a time step with three edges, then,
+#' even if one of its edges is dissolved during its time step, it won't be able
+#' to form another edge until the next time step. This behavior may change in
+#' the future.
+#' 
+#' Note that not all possible combinations of constraints are supported.
+#' @param monitor Either a one-sided formula specifying one or more terms whose
+#' value is to be monitored, or a string containing \code{"formation"} or
+#' \code{"dissolution"}, to monitor their respective terms, or \code{"all"} to
+#' monitor distinct terms from both.
+#' @param time.slices Number of time slices (or statistics) to return from each
+#' replication of the dynamic process. See below for return types. Defaults to
+#' 1, which, if \code{time.burnin==0} and \code{time.interval==1} (the
+#' defaults), advances the process one time step.
+#' @param time.start An optional argument specifying the time point at which
+#' the simulation is to start. See Details for further information.
+#' @param time.burnin Number of time steps to discard before starting to
+#' collect network statistics. Actual network will only be returned if
+#' \code{time.burnin==0}.
+#' @param time.interval Number of time steps between successive recordings of
+#' network statistics. Actual network will only be returned if
+#' \code{time.interval==1}.
+#' @param time.offset Argument specifying the offset between the point when the
+#' state of the network is sampled (\code{time.start}) and the the beginning of
+#' the spell that should be recorded for the newly simulated network state.
+#' @param control A list of control parameters for algorithm tuning.
+#' Constructed using \code{\link{control.simulate.stergm}} or
+#' \code{\link{control.simulate.network}}.
+#' @param statsonly Deprecated in favor of \code{output}.
+#' @param output A character vector specifying output type: one of
+#' "networkDynamic" (the default), "stats", and "changes", with partial
+#' matching allowed. See Value section for details.
+#' @param nw.start A specification for the starting network to be used by
+#' \code{simulate.stergm}, optional for EGMME fits, but required for CMLE and
+#' CMPLE fits: \describe{ \item{a numeric index }{use \code{i}th time-point's
+#' network, where the first network in the series used to fit the model is
+#' defined to be at the first time point;}
+#' \item{`i`}{use \code{i}th
+#' time-point's network, where the first network in the series used to fit the
+#' model is defined to be at the first time point;}
+#' \item{`"first"` or `"last"`}{the first or last time point used in
+#' fitting the model; or}
+#' \item{`network`}{specify the network directly.}
+#' }
+#' \code{\link{networkDynamic}}s
+#' cannot be used as starting networks for \code{simulate.stergm} at this time.
+#' (They can be used as starting networks for \code{simulate.networkDynamic},
+#' of course.)
+#' @param stats.form,stats.diss Logical: Whether to return
+#' formation/dissolution model statistics. This is not the recommended method:
+#' use \code{monitor} argument instead.
+#' @param duration.dependent Logical: Whether the model terms in formula or
+#' model are duration dependent. E.g., if a duration-dependent term is used in
+#' estimation/simulation model, the probability of forming or dissolving a tie
+#' may dependent on the age the dyad status.
+#' @param verbose Logical: If TRUE, extra information is printed as the Markov
+#' chain progresses.
+#' @param \dots Further arguments passed to or used by methods.
+#' @return Depends on the \code{output} argument:
+#'  \item{"stats"}{If \code{stats.form==FALSE} and
+#'    \code{stats.diss==FALSE}, an \code{\link{mcmc}} matrix with
+#'    monitored statistics, and if either of them is \code{TRUE}, a
+#'    list containing elements \code{stats} for statistics specified in the
+#'    \code{monitor} argument, and \code{stats.form} and \code{stats.diss}
+#'    for the respective formation and dissolution statistics.
+#'    If \code{stats.form==FALSE} and
+#'    \code{stats.diss==FALSE} and no monitored statistics are specified,
+#'    an empty list is returned, with a warning.
+#'    When \code{nsim>1}, an \code{\link{mcmc.list}} (or list of them) of
+#'    the statistics is returned instead.}
+#'  \item{"networkDynamic"}{A \code{\link[networkDynamic]{networkDynamic}}
+#'    object representing the simulated process, with ties present in the
+#'    initial network having onset \code{-Inf} and ties present at the end
+#'    of the simulation having terminus \code{+Inf}. The method for
+#'    \code{\link[networkDynamic]{networkDynamic}} returns the initial
+#'    \code{\link[networkDynamic]{networkDynamic}} with simulated changes
+#'    applied to it. The \code{\link{net.obs.period}} network attribute is
+#'    updated (or added if not existing) to reflect the time period that was
+#'    simulated. If the network does not have any \code{\link[networkDynamic]{persistent.ids}} 
+#'    defined for vertices, a vertex.pid will be attached in a vertex attribute 
+#'    named \code{'tergm_pid'} to facilitate 'bookkeeping' between the networkDynamic 
+#'    argument and the simulated network time step.
+#'    Additionally, attributes (\code{\link{attr}}, not network
+#'    attributes) are attached as follows:
+#'    \describe{
+#'      \item{\code{formation}, \code{dissolution}, \code{monitor}:}{Formation, dissolution,
+#'	and monitoring formulas	used in the simulation,	respectively.}
+#'      \item{\code{stats}, \code{stats.form}, \code{stats.diss}:}{Network statistics as above.}
+#'      \item{\code{coef.form}, \code{coef.diss}:}{Coefficients used in the simulation.}
+#'      \item{\code{changes}:}{A four-column matrix summarizing the changes in the
+#'	\code{"changes"} output. (This may be removed in the future.)}
+#'    } 
+#'    When \code{nsim>1}, a \code{\link{network.list}} of these
+#'    \code{\link{networkDynamic}}s is returned.
+#'  }
+#'  
+#'  \item{"changes"}{An integer matrix with four columns (\code{time},
+#'      \code{tail}, \code{head}, and \code{to}), giving the time-stamped
+#'      changes relative to the current network. \code{to} is \code{1} if
+#'      a tie was formed and \code{0} if a tie was dissolved. The
+#'      convention for \code{time} is that it gives the time point during
+#'      which the change is effective. For example, a row
+#'      \code{c(5,2,3,1)} indicates that between time \eqn{4} and \eqn{5},
+#'      a tie from node \eqn{2} to node \eqn{3} was formed, so that it was
+#'      absent at time point \eqn{4} and present at time point \eqn{5};
+#'      while a row \code{c(5,2,3,0)} indicates that in that time, that
+#'      tie was dissolved, so that it is was present at time point \eqn{4}
+#'      and absent at time point \eqn{5}.
+#'      Additionally, same attributes (\code{\link{attr}}, not network
+#'      attributes) as with \code{output=="networkDynamic"} are attached.
+#'      When \code{nsim>1}, a list of these change matrices is returned.}
+#'    \item{"final"}{A \code{\link[network]{network}}
+#'    object representing the last network in the series generated. This
+#'    is not implemented in the method for
+#'    \code{\link[networkDynamic]{networkDynamic}}.
+#'    \code{\link{lasttoggle}} attributes are also included.
+#'    Additionally, attributes (\code{\link{attr}}, not network
+#'    attributes) are attached as follows:
+#'    \describe{
+#'      \item{formation, dissolution, monitor:}{Formation, dissolution,
+#'	and monitoring formulas	used in the simulation,	respectively.}
+#'      \item{stats, stats.form, stats.diss:}{Network statistics as above.}
+#'      \item{coef.form, coef.diss:}{Coefficients used in the simulation.}
+#'      \item{changes}{A four-column matrix summarizing the changes in the
+#'	\code{"changes"} output. (This may be removed in the future.)}
+#'    }
+#'    When \code{nsim>1}, a \code{\link{network.list}} of these
+#'    \code{\link{network}}s is returned.
+#'  }
+#' @examples
+#' 
+#' logit<-function(p)log(p/(1-p))
+#' coef.form.f<-function(coef.diss,density) -log(((1+exp(coef.diss))/(density/(1-density)))-1)
+#' 
+#' # Construct a network with 20 nodes and 20 edges
+#' n<-20
+#' target.stats<-edges<-20
+#' g0<-network.initialize(n,dir=TRUE)
+#' g1<-san(g0~edges,target.stats=target.stats,verbose=TRUE)
+#' 
+#' S<-10
+#' 
+#' # To get an average duration of 10...
+#' duration<-10
+#' coef.diss<-logit(1-1/duration)
+#' 
+#' # To get an average of 20 edges...
+#' dyads<-network.dyadcount(g1)
+#' density<-edges/dyads
+#' coef.form<-coef.form.f(coef.diss,density)
+#' 
+#' # ... coefficients.
+#' print(coef.form)
+#' print(coef.diss)
+#' 
+#' # Simulate a networkDynamic
+#' dynsim<-simulate(g1,formation=~edges,dissolution=~edges,
+#'                  coef.form=coef.form,coef.diss=coef.diss,
+#'                  time.slices=S,verbose=TRUE)
+#' 
+#' # "Resume" the simulation.
+#' dynsim2<-simulate(dynsim,time.slices=S,verbose=TRUE)
+#' @importFrom stats simulate
+#' @S3method simulate stergm
+#' @export simulate.stergm
 simulate.stergm<-function(object, nsim=1, seed=NULL,
                           coef.form=object$formation.fit$coef,coef.diss=object$dissolution.fit$coef,
                           constraints = object$constraints,
@@ -93,6 +326,7 @@ simulate.stergm<-function(object, nsim=1, seed=NULL,
                           stats.diss = FALSE,
                           duration.dependent = NULL,
                           verbose=FALSE, ...){
+  .dep_method("simulate","stergm")
   check.control.class(c("simulate.stergm","simulate.network"), "simulate.stergm")
   
   control.transfer <- list(MCMC.prop.weights="MCMC.prop.weights",
@@ -136,7 +370,9 @@ simulate.stergm<-function(object, nsim=1, seed=NULL,
 
 
 
-# Note that we are overriding simulate.network here, since the first argument is a network.
+#' @rdname simulate.stergm
+#' @S3method simulate network
+#' @export simulate.network
 simulate.network <- function(object, nsim=1, seed=NULL,
                              formation, dissolution,
                              coef.form,coef.diss,
@@ -150,6 +386,7 @@ simulate.network <- function(object, nsim=1, seed=NULL,
                              stats.diss = FALSE,
                              duration.dependent=NULL,
                              verbose=FALSE,...) {
+  .dep_method("simulate","network")
   if(length(list(...))) stop("Unknown arguments: ",names(list(...)))
   check.control.class("simulate.network", "STERGM simulate.network")
 
@@ -180,8 +417,8 @@ simulate.network <- function(object, nsim=1, seed=NULL,
     stop("A network object must be given")
   }
 
-  formation<-ergm.update.formula(formation,nw~., from.new="nw")
-  dissolution<-ergm.update.formula(dissolution,nw~., from.new="nw")
+  formation<-nonsimp_update.formula(formation,nw~., from.new="nw")
+  dissolution<-nonsimp_update.formula(dissolution,nw~., from.new="nw")
 
   unset.offset.call <- function(object){
     if(inherits(object,"call") && object[[1]]=="offset")
@@ -194,11 +431,11 @@ simulate.network <- function(object, nsim=1, seed=NULL,
     monitor <- switch(monitor,
                       formation = formation,
                       dissolution = dissolution,
-                      all = append.rhs.formula(~nw, unique(lapply(c(term.list.formula(formation[[3]]),term.list.formula(dissolution[[3]])), unset.offset.call)))
+                      all = append_rhs.formula(~nw, unique(lapply(c(list_rhs.formula(formation),list_rhs.formula(dissolution)), unset.offset.call)))
                       )
   }
   
-  if(!is.null(monitor)) monitor<-ergm.update.formula(monitor,nw~., from.new="nw")
+  if(!is.null(monitor)) monitor<-nonsimp_update.formula(monitor,nw~., from.new="nw")
   
   if(is.null(duration.dependent)){ # in the case of simulating from nw directly 
     duration.dependent <- is.lasttoggle(nw,formation,dissolution,monitor)
@@ -209,27 +446,27 @@ simulate.network <- function(object, nsim=1, seed=NULL,
 
 
 
-  model.form <- ergm.getmodel(formation, nw, role="formation")
-  if(!missing(coef.form) && coef.length.model(model.form)!=length(coef.form)) stop("coef.form has ", length(coef.form), " elements, while the model requires ",coef.length.model(model.form)," parameters.")
+  model.form <- ergm_model(formation, nw, role="formation")
+  if(!missing(coef.form) && nparam(model.form)!=length(coef.form)) stop("coef.form has ", length(coef.form), " elements, while the model requires ",nparam(model.form)," parameters.")
 
-  model.diss <- ergm.getmodel(dissolution, nw, role="dissolution")
-  if(!missing(coef.diss) && coef.length.model(model.diss)!=length(coef.diss)) stop("coef.diss has ", length(coef.diss), " elements, while the model requires ",coef.length.model(model.diss)," parameters.")
+  model.diss <- ergm_model(dissolution, nw, role="dissolution")
+  if(!missing(coef.diss) && nparam(model.diss)!=length(coef.diss)) stop("coef.diss has ", length(coef.diss), " elements, while the model requires ",nparam(model.diss)," parameters.")
 
-  model.mon <- if(!is.null(monitor)) ergm.getmodel(monitor, nw, role="target") else NULL
+  model.mon <- if(!is.null(monitor)) ergm_model(monitor, nw, role="target") else NULL
   
   if(missing(coef.form)) {
-    coef.form <- rep(0,length(model.form$coef.names))
+    coef.form <- rep(0,nparam(model.form, canonical=TRUE))
     warning("No parameter values given, using Bernouli formation.\nThis means that every time step, half the non-tie dyads will gain a tie!")
   }
 
   if(missing(coef.diss)) {
-    coef.diss <- rep(0,length(model.diss$coef.names))
+    coef.diss <- rep(0,nparam(model.diss, canonical=TRUE))
     warning("No parameter values given, using Bernoulli dissolution.\nThis means that every time step, half the ties get dissolved!\n")
   }
     
-  MHproposal.form <- MHproposal(constraints,control$MCMC.prop.args.form,nw,
+  proposal.form <- ergm_proposal(constraints,control$MCMC.prop.args.form,nw,
                                 weights=control$MCMC.prop.weights.form,class="f")
-  MHproposal.diss <- MHproposal(constraints,control$MCMC.prop.args.diss,nw,
+  proposal.diss <- ergm_proposal(constraints,control$MCMC.prop.args.diss,nw,
                                 weights=control$MCMC.prop.weights.diss,class="d")
 
   eta.form <- ergm.eta(coef.form, model.form$etamap)
@@ -244,9 +481,9 @@ simulate.network <- function(object, nsim=1, seed=NULL,
   out <- replicate(nsim, {
     nw <- .set.default.net.obs.period(nw, time.start)
     nw %n% "time" <- start <- .get.last.obs.time(nw, time.start)
-    z <- stergm.getMCMCsample(nw, model.form, model.diss, model.mon,
-                              MHproposal.form, MHproposal.diss,
-                              eta.form, eta.diss, control, verbose)
+    z <- stergm_MCMC_sample(nw, model.form, model.diss, model.mon,
+                              proposal.form, proposal.diss,
+                              eta.form=eta.form, eta.diss=eta.diss, control=control, verbose=verbose)
     
     stats.form <- if(control$collect.form) mcmc(sweep(z$statsmatrix.form,2,summary(formation),"+"),start=time.burnin+1,thin=time.interval)
     stats.diss <- if(control$collect.diss) mcmc(sweep(z$statsmatrix.diss,2,summary(dissolution),"+"),start=time.burnin+1,thin=time.interval)
@@ -364,7 +601,9 @@ simulate.network <- function(object, nsim=1, seed=NULL,
            })
   }
 }
-
+#' @rdname simulate.stergm
+#' @S3method simulate networkDynamic
+#' @export simulate.networkDynamic
 simulate.networkDynamic <- function(object, nsim=1, seed=NULL,
                                     formation = attr(object, "formation"), dissolution = attr(object, "dissolution"),
                                     coef.form = attr(object, "coef.form"), coef.diss = attr(object, "coef.diss"),
@@ -378,6 +617,7 @@ simulate.networkDynamic <- function(object, nsim=1, seed=NULL,
                                     stats.diss = FALSE,
                                     duration.dependent = NULL,
                                     verbose=FALSE, ...){
+  .dep_method("simulate","networkDynamic")
   
   if(nsim>1) stop("Simulating more than one chain of networks is not supported at this time. If you want to simulate over multiple time steps, use the time.slices argument.")
 
@@ -443,8 +683,8 @@ simulate.networkDynamic <- function(object, nsim=1, seed=NULL,
   }
   
   attributes(object) <- c(attributes(object), # Don't clobber existing attributes!
-                          list(formation = ergm.update.formula(formation,nw~., from.new="nw"),
-                               dissolution = ergm.update.formula(dissolution,nw~., from.new="nw"),
+                          list(formation = nonsimp_update.formula(formation,nw~., from.new="nw"),
+                               dissolution = nonsimp_update.formula(dissolution,nw~., from.new="nw"),
                                stats.form = rbind(if(isTRUE(attr(sim,"formation")==attr(object,"formation"))) attr(object,"stats.form"),attr(sim,"stats.form")),
                                stats.diss = rbind(if(isTRUE(attr(sim,"dissolution")==attr(object,"dissolution"))) attr(object,"stats.diss"),attr(sim,"stats.diss")),
                                monitor = attr(sim,"monitor"),
