@@ -5,7 +5,7 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  http://statnet.org/attribution
 #
-#  Copyright 2008-2017 Statnet Commons
+#  Copyright 2008-2018 Statnet Commons
 #######################################################################
 stergm.CMLE <- function(nw, formation, dissolution, constraints, times, offset.coef.form, offset.coef.diss,
                         eval.loglik,
@@ -74,10 +74,10 @@ stergm.CMLE <- function(nw, formation, dissolution, constraints, times, offset.c
           2*abs(target-current)/(abs(target)+abs(current))<tolerance # Some statistics don't give exact equality.
         
       bad.stat <-
-        !(c(eql(apply(rbind(sapply(y0s, function(nw) summary(ergm.update.formula(formation,nw~., from.new="nw")))),1,sum), summary(ergm.update.formula(formation,y0~., from.new="y0"))),
-            eql(apply(rbind(sapply(y0s, function(nw) summary(ergm.update.formula(dissolution,nw~., from.new="nw")))),1,sum), summary(ergm.update.formula(dissolution,y0~., from.new="y0")))) &
-          c(eql(apply(rbind(sapply(y1s, function(nw) summary(ergm.update.formula(formation,nw~., from.new="nw")))),1,sum), summary(ergm.update.formula(formation,y1~., from.new="y1"))),
-            eql(apply(rbind(sapply(y1s, function(nw) summary(ergm.update.formula(dissolution,nw~., from.new="nw")))),1,sum), summary(ergm.update.formula(dissolution,y1~., from.new="y1")))))
+        !(c(eql(apply(rbind(sapply(y0s, function(nw) summary(nonsimp_update.formula(formation,nw~., from.new="nw")))),1,sum), summary(nonsimp_update.formula(formation,y0~., from.new="y0"))),
+            eql(apply(rbind(sapply(y0s, function(nw) summary(nonsimp_update.formula(dissolution,nw~., from.new="nw")))),1,sum), summary(nonsimp_update.formula(dissolution,y0~., from.new="y0")))) &
+          c(eql(apply(rbind(sapply(y1s, function(nw) summary(nonsimp_update.formula(formation,nw~., from.new="nw")))),1,sum), summary(nonsimp_update.formula(formation,y1~., from.new="y1"))),
+            eql(apply(rbind(sapply(y1s, function(nw) summary(nonsimp_update.formula(dissolution,nw~., from.new="nw")))),1,sum), summary(nonsimp_update.formula(dissolution,y1~., from.new="y1")))))
       if(any(bad.stat)) stop("Fitting the term(s) ", paste.and(unique(names(bad.stat)[bad.stat])), " over multiple network transitions is not supported at this time.")
     }
   }else{
@@ -93,21 +93,21 @@ stergm.CMLE <- function(nw, formation, dissolution, constraints, times, offset.c
   
   y.form <- y0 | y1
   y.form <- nvattr.copy.network(y.form, y0)
-  formation <- ergm.update.formula(formation, y.form~., from.new="y.form")
+  formation <- nonsimp_update.formula(formation, y.form~., from.new="y.form")
 
   y.diss <- y0 & y1
   y.diss <- nvattr.copy.network(y.diss, y0)
-  dissolution <- ergm.update.formula(dissolution, y.diss~., from.new="y.diss")
+  dissolution <- nonsimp_update.formula(dissolution, y.diss~., from.new="y.diss")
 
   # Construct new constraints
 
-  constraints.form <- if(constraints==~.) ~atleast(y0) else ergm.update.formula(constraints, ~.+atleast(y0), from.new="y0")
-  if(length(times)>2) constraints.form <- ergm.update.formula(constraints.form, ~.+blockdiag(".stergm.CMLE.time.index"))
+  constraints.form <- if(constraints==~.) ~atleast(y0) else nonsimp_update.formula(constraints, ~.+atleast(y0), from.new="y0")
+  if(length(times)>2) constraints.form <- nonsimp_update.formula(constraints.form, ~.+blockdiag(".stergm.CMLE.time.index"))
   # TODO: Some unlucky variable names can break this. We need to figure out a way around this.
   environment(constraints.form) <- environment()
   
-  constraints.diss <- if(constraints==~.) ~atmost(y0) else ergm.update.formula(constraints, ~.+atmost(y0), from.new="y0")
-  if(length(times)>2) constraints.diss <- ergm.update.formula(constraints.diss, ~.+blockdiag(".stergm.CMLE.time.index"))
+  constraints.diss <- if(constraints==~.) ~atmost(y0) else nonsimp_update.formula(constraints, ~.+atmost(y0), from.new="y0")
+  if(length(times)>2) constraints.diss <- nonsimp_update.formula(constraints.diss, ~.+blockdiag(".stergm.CMLE.time.index"))
   # TODO: Some unlucky variable names can break this. We need to figure out a way around this.
   environment(constraints.diss) <- environment()
   
@@ -115,8 +115,8 @@ stergm.CMLE <- function(nw, formation, dissolution, constraints, times, offset.c
   if(is.null(control$CMLE.control.form$init)) control$CMLE.control.form$init <- control$init.form
   if(is.null(control$CMLE.control.diss$init)) control$CMLE.control.diss$init <- control$init.diss
  
-  model.form<-ergm.getmodel(formation, y.form, initialfit=TRUE)
-  model.diss<-ergm.getmodel(dissolution, y.diss, initialfit=TRUE)
+  model.form<-ergm_model(formation, y.form, initialfit=TRUE)
+  model.diss<-ergm_model(dissolution, y.diss, initialfit=TRUE)
 
   if(!is.null(control$CMLE.control.form$init)){
     # Check length of control$CMLE.control.form$init.
