@@ -5,7 +5,7 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  http://statnet.org/attribution
 #
-#  Copyright 2008-2017 Statnet Commons
+#  Copyright 2008-2018 Statnet Commons
 #######################################################################
 # Keeps a list of "named" graphic devices.
 #
@@ -16,6 +16,7 @@
 # available, creates a new device, switches to it, and "remembers" the
 # name.
 
+#' @import grDevices
 get.dev <- local({
   devs <- list()
   function(name){    
@@ -60,7 +61,7 @@ network.extract.with.lasttoggle <- function(nwd, at, duration.dependent){
   if (is.null(nwd%n%'vertex.pid')){
 	  nw %v% "tergm_pid" <- which(is.active(nwd, at=at, v=seq_len(network.size(nwd))))
   }
-	if(duration.dependent==1){
+	if(duration.dependent){
 		lttails <- lapply(nw$mel, "[[", "outl")
 		ltheads <- lapply(nw$mel, "[[", "inl")
 		ltlts <- lapply(lapply(lapply(nw$mel, "[[", "atl"), "[[", 
@@ -86,7 +87,8 @@ network.extract.with.lasttoggle <- function(nwd, at, duration.dependent){
 	else {  # non-duration dependent model
 		lasttoggle <- NULL
 	}
-	
+
+        nw <- network.collapse(nwd, at=at) #  Convert to a network network.
 	nw %n% "time" <- at
 	nw %n% "lasttoggle" <- lasttoggle
 	nw
